@@ -1,6 +1,5 @@
 from cliff.command import Command
 import argparse
-import os
 
 
 class Manage(Command):
@@ -12,7 +11,6 @@ class Manage(Command):
         return parser
 
     def take_action(self, parsed_args):
-        os.environ['ENOUGH_DOMAIN'] = self.app.options.domain
         try:
             from django.core.management import execute_from_command_line
         except ImportError as exc:
