@@ -178,12 +178,6 @@ class Enough(object):
         self._clone_volume_from_snapshot_cleanup(clone, from_volume)
         clone.openstack.o.volume.set('--name', snapshot, to_volume)
 
-    def create_volume_from_snapshot(self, snapshot, volume):
-        if not self.openstack.o.volume.list(
-                '-c', 'Name', '--format=value',
-                '--name', volume).strip() == volume:
-            self.openstack.o.volume.create('--snapshot', snapshot, volume)
-
     def _clone_volume_from_snapshot_body(self, clone, snapshot):
         #
         #         in the current region
@@ -191,7 +185,7 @@ class Enough(object):
         #
         volume_name = self.volume_from_snapshot(snapshot)
         from_volume = f'copy-from-{volume_name}'
-        self.create_volume_from_snapshot(snapshot, from_volume)
+        self.openstack.create_volume_from_snapshot(snapshot, from_volume)
 
         size = self.openstack.o.volume.show(
             '-c', 'size', '--format=value', from_volume).strip()
@@ -257,7 +251,7 @@ class Enough(object):
     def restore_local(self, snapshot):
         host = self.host_from_snapshot(snapshot)
         volume = snapshot
-        self.create_volume_from_snapshot(snapshot, volume)
+        self.openstack.create_volume_from_snapshot(snapshot, volume)
         self.openstack.replace_volume(host, volume, delete_volume=False)
         return self
 
@@ -302,3 +296,21 @@ class Enough(object):
                                                  show_passwords=self.args.get('show_passwords'))
                 info.append(f'\t{service}\t{" ".join(service_info)}')
         return info
+
+    def backup_download(self):
+        if self.args.get('driver') == 'openstack':
+            self.openstack.backup_download(
+                self.args['volumes'], self.args['hosts'], self.args['recent'])
+
+    def backup_create(self):
+        if self.args.get('driver') == 'openstack':
+            self.openstack.backup_create(self.args['volumes'])
+        elif self.args.get('driver') == 'libvirt':
+            self.libvirt.backup_create(OpenStack(self.config_dir, **self.args))
+
+    def backup_prune(self):
+        if self.args.get('driver') == 'openstack':
+            self.openstack.backup_prune(self.args['days'])
+            self.openstack.volume_prune(self.args['days'])
+        elif self.args.get('driver') == 'libvirt':
+            self.libvirt.backup_prune(OpenStack(self.config_dir, **self.args))
