@@ -120,9 +120,12 @@ class DotEnough(object):
         self.set_bind_service_group()
 
     def set_bind_service_group(self):
-        i = f'{self.config_dir}/inventory'
-        if not os.path.exists(f'{i}/services.yml'):
-            open(f'{i}/services.yml', 'w').write(textwrap.dedent(f"""\
+        self._set_bind_service_group(f'{self.config_dir}/inventory/services.yml')
+
+    @staticmethod
+    def _set_bind_service_group(services_pathname):
+        if not os.path.exists(services_pathname):
+            open(services_pathname, 'w').write(textwrap.dedent(f"""\
             ---
             essential-service-group:
                hosts:
