@@ -472,6 +472,9 @@ class OpenStack(OpenStackBase):
         snapshots = self._backup_map()
         count = 0
         for volume in volumes:
+            if re.match(r'^\d\d\d\d\-\d\d-\d\d-', volume):
+                log.info(f'skipping {volume} because it starts with a date')
+                continue
             s = f'{date}-{volume}'
             if s not in snapshots:
                 self.o.volume.snapshot.create('--force', '--volume', volume, s)
