@@ -16,6 +16,7 @@ class InstallScript(Command):
         parser.add_argument('--registry')
         parser.add_argument('--function', action='store_true')
         parser.add_argument('--no-version', action='store_true')
+        parser.add_argument('--no-tty', action='store_true')
         parser.add_argument('path', nargs='?')
         return parser
 
@@ -31,6 +32,10 @@ class InstallScript(Command):
             self.registry = parsed_args.registry
         else:
             self.registry = 'enoughcommunity/'
+        if parsed_args.no_tty:
+            self.tty = ''
+        else:
+            self.tty = '-ti'
         if parsed_args.no_version:
             self.version = ''
         else:
