@@ -1,10 +1,8 @@
-import os
 import pytest
-import shutil
 import yaml
 
 from enough.common import Enough
-from tests import make_config_dir, prepare_config_dir
+from tests import InfrastructureOpenStack, InfrastructureLibvirt
 
 
 def pytest_addoption(parser):
@@ -23,6 +21,12 @@ def pytest_addoption(parser):
         action="store_true",
         help="Do not run the destroy step"
     )
+    parser.addoption(
+        "--enough-driver",
+        default='openstack',
+        choices=['libvirt', 'openstack'],
+        help="Infrastructure driver libvirt or openstack"
+    )
 
 
 def pytest_configure(config):
@@ -36,27 +40,41 @@ def get_hosts(session, enough):
 
 
 def pytest_sessionstart(session):
+    service_directory = session.config.getoption("--enough-service")
+
+    enough_dot_dir = session.config.cache.makedir('dotenough')
+
+    driver = session.config.getoption("--enough-driver")
+    if driver == 'openstack':
+        session.infrastructure = InfrastructureOpenStack()
+    elif driver == 'libvirt':
+        session.infrastructure = InfrastructureLibvirt()
+    session.infrastructure.prefix_set(service_directory)
+    session.infrastructure.domain_set()
+    session.infrastructure.config_dir_set(enough_dot_dir)
+
+    if not session.config.getoption("--enough-no-destroy"):
+        hosts = session.config.getoption("--enough-hosts").split(',')
+        session.infrastructure.destroy(hosts)
+        session.infrastructure.clobber()
+
     if session.config.getoption("--enough-no-create"):
         return
 
-    if not session.config.getoption("--enough-no-destroy"):
-        enough_destroy(session)
+    session.infrastructure.prepare_config_dir(enough_dot_dir)
 
-    service_directory = session.config.getoption("--enough-service")
-    domain = f'{service_directory}.test'
-    enough_dot_dir = session.config.cache.makedir('dotenough')
-    config_dir = prepare_config_dir(domain, enough_dot_dir)
-
-    e = Enough(config_dir, '.',
-               domain=domain,
-               driver='openstack',
+    e = Enough(session.infrastructure.config_dir, '.',
+               domain=session.infrastructure.domain,
+               driver=driver,
                inventory=[f'playbooks/{service_directory}/inventory'],
                route_to_internal=False)
     (vpn_host, hosts) = get_hosts(session, e)
     r = e.create_missings(hosts)
     with open(f'{e.config_dir}/inventory/group_vars/all/domain.yml', 'r') as f:
         data = yaml.safe_load(f)
-    if len(r) > 0 or data.get('domain') == domain:
+    if (driver == 'openstack' and
+        (len(r) > 0 or
+         data.get('domain') == session.infrastructure.domain)):
         e.heat.create_test_subdomain('enough.community')
     if vpn_host in hosts:
         if not e.vpn_has_credentials():
@@ -86,24 +104,11 @@ def pytest_runtest_setup(item):
 
 
 def pytest_sessionfinish(session, exitstatus):
-    if not session.config.getoption("--enough-no-destroy"):
-        enough_destroy(session)
-
-
-def enough_destroy(session):
-    service_directory = session.config.getoption("--enough-service")
-    domain = f'{service_directory}.test'
-    enough_dot_dir = session.config.cache.makedir('dotenough')
-    config_dir = make_config_dir(domain, enough_dot_dir)
-    all_dir = f'{config_dir}/inventory/group_vars/all'
-    if not os.path.exists(all_dir):
-        os.makedirs(all_dir)
-    shutil.copyfile('inventory/group_vars/all/clouds.yml', f'{all_dir}/clouds.yml')
-    e = Enough(config_dir, '.',
-               domain=domain,
-               driver='openstack',
-               inventory=[f'playbooks/{service_directory}/inventory'])
-    e.destroy()
+    if session.config.getoption("--enough-no-destroy"):
+        return
+    hosts = session.config.getoption("--enough-hosts").split(',')
+    session.infrastructure.destroy(hosts)
+    session.infrastructure.clobber()
 
 
 def pytest_unconfigure(config):
