@@ -14,7 +14,7 @@ from tests import prepare_config_dir
 
 
 @pytest.mark.openstack_integration
-def test_clone_and_destroy(request, tmpdir):
+def test_clone_and_destroy(tmpdir):
 
     clone_override_dir = f'{tmpdir}/clone-override'
     shutil.copytree('tests/enough/common/test_init/clone-override',
@@ -105,7 +105,7 @@ def create_and_clone_server_and_volume(tmpdir):
 
 
 @pytest.mark.openstack_integration
-def test_clone_create_service(request, tmpdir):
+def test_clone_create_service(tmpdir):
     try:
         (original, clone) = create_and_clone_server_and_volume(tmpdir)
         assert 'sample-host' in original.openstack.o.server.list()
@@ -114,13 +114,13 @@ def test_clone_create_service(request, tmpdir):
         assert 'sample-volume' in clone.openstack.o.volume.list()
     finally:
         for cloud in ('production', 'clone'):
-            o = OpenStack(settings.CONFIG_DIR, cloud=cloud)
+            o = OpenStack(original.config_dir, cloud=cloud)
             # comment out the following line to re-use the content of the regions and save time
             o.destroy_everything(None)
 
 
 @pytest.mark.openstack_integration
-def test_create_copy_host(request, tmpdir):
+def test_create_copy_host(tmpdir):
     try:
         enough = create_enough(tmpdir, 'copy')
         if 'copy-volume' not in enough.openstack.o.volume.list():
@@ -134,34 +134,34 @@ def test_create_copy_host(request, tmpdir):
                    '-i', enough.dotenough.private_key(), f'root@{ip}', 'mountpoint', '/srv').strip()
         assert r == '/srv is a mountpoint'
     finally:
-        o = OpenStack(settings.CONFIG_DIR)
+        o = OpenStack(enough.config_dir)
         # comment out the following line to re-use the content of the regions and save time
         o.destroy_everything(None)
 
 
 @pytest.mark.openstack_integration
-def test_create_volume_from_snapshot(request, tmpdir):
+def test_create_volume_from_snapshot(tmpdir):
     try:
         e = create_enough(tmpdir, 'backup')
         e.set_args(name='sample', playbook='enough-playbook.yml')
         e.service.create_or_update()
         e.openstack.backup_create(['sample-volume'])
-        snapshot = f'{e.openstack.backup_date()}-sample-volume'
+        snapshot = f'{e.openstack.backup_name_create("sample-volume")}'
         assert snapshot in e.openstack.o.volume.snapshot.list()
 
         volume = 'test-volume'
-        e.create_volume_from_snapshot(snapshot, volume)
+        e.openstack.create_volume_from_snapshot(snapshot, volume)
 
         assert volume in e.openstack.o.volume.list()
 
     finally:
-        o = OpenStack(settings.CONFIG_DIR)
+        o = OpenStack(e.config_dir)
         # comment out the following line to re-use the content of the regions and save time
         o.destroy_everything(None)
 
 
 @pytest.mark.openstack_integration
-def test_clone_volume_from_snapshot(request, tmpdir):
+def test_clone_volume_from_snapshot(tmpdir):
     try:
         original = create_enough(tmpdir, 'backup')
         original.set_args(name='sample', playbook='enough-playbook.yml')
@@ -173,7 +173,7 @@ def test_clone_volume_from_snapshot(request, tmpdir):
         sh.ssh('-oStrictHostKeyChecking=no',
                '-i', original.dotenough.private_key(), f'debian@{ip}', 'sync')
         original.openstack.backup_create(['sample-volume'])
-        snapshot = f'{original.openstack.backup_date()}-sample-volume'
+        snapshot = f'{original.openstack.backup_name_create("sample-volume")}'
         assert snapshot in original.openstack.o.volume.snapshot.list()
 
         clone_domain = 'clone.com'
@@ -199,13 +199,13 @@ def test_clone_volume_from_snapshot(request, tmpdir):
 
     finally:
         for cloud in ('production', 'clone'):
-            o = OpenStack(settings.CONFIG_DIR, cloud=cloud)
+            o = OpenStack(original.config_dir, cloud=cloud)
             # comment out the following line to re-use the content of the regions and save time
             o.destroy_everything(None)
 
 
 @pytest.mark.openstack_integration
-def test_create_service_matching_snapshot(request, tmpdir):
+def test_create_service_matching_snapshot(tmpdir):
     try:
         enough = create_enough(tmpdir, 'backup')
         host = enough.create_service_matching_snapshot('2020-02-20-sample-volume')
@@ -213,13 +213,13 @@ def test_create_service_matching_snapshot(request, tmpdir):
         assert 'sample-volume' in enough.openstack.o.volume.list()
 
     finally:
-        o = OpenStack(settings.CONFIG_DIR)
+        o = OpenStack(enough.config_dir)
         # comment out the following line to re-use the content of the regions and save time
         o.destroy_everything(None)
 
 
 @pytest.mark.openstack_integration
-def test_restore_remote(request, tmpdir):
+def test_restore_remote(tmpdir):
     try:
         original = create_enough(tmpdir, 'backup')
         original.set_args(name='sample', playbook='enough-playbook.yml')
@@ -233,7 +233,7 @@ def test_restore_remote(request, tmpdir):
                '-i', original.dotenough.private_key(), f'-p{port}',
                f'debian@{ip}', 'touch', '/srv/STONE')
         original.openstack.backup_create(['sample-volume'])
-        snapshot = f'{original.openstack.backup_date()}-sample-volume'
+        snapshot = f'{original.openstack.backup_name_create("sample-volume")}'
         assert snapshot in original.openstack.o.volume.snapshot.list()
 
         # original host isn't needed anymore
@@ -258,13 +258,13 @@ def test_restore_remote(request, tmpdir):
 
     finally:
         for cloud in ('production', 'clone'):
-            o = OpenStack(settings.CONFIG_DIR, cloud=cloud)
+            o = OpenStack(original.config_dir, cloud=cloud)
             # comment out the following line to re-use the content of the regions and save time
             o.destroy_everything(None)
 
 
 @pytest.mark.openstack_integration
-def test_restore_local(request, tmpdir):
+def test_restore_local(tmpdir):
     try:
         e = create_enough(tmpdir, 'backup')
         e.set_args(name='sample', playbook='enough-playbook.yml')
@@ -279,7 +279,7 @@ def test_restore_local(request, tmpdir):
         e.openstack.backup_create(['sample-volume'])
         sh.ssh('-oStrictHostKeyChecking=no', '-i', e.dotenough.private_key(),
                f'-p{port}', f'debian@{ip}', 'rm', '/srv/STONE')
-        snapshot = f'{e.openstack.backup_date()}-sample-volume'
+        snapshot = f'{e.openstack.backup_name_create("sample-volume")}'
         assert snapshot in e.openstack.o.volume.snapshot.list()
 
         assert e == e.restore_local(snapshot)
@@ -291,13 +291,13 @@ def test_restore_local(request, tmpdir):
         assert res.exit_code == 0, f'Unexpected SSH exit code: {res.exit_code}'
 
     finally:
-        o = OpenStack(settings.CONFIG_DIR)
+        o = OpenStack(e.config_dir)
         # comment out the following line to re-use the content of the regions and save time
         o.destroy_everything(None)
 
 
 @pytest.mark.openstack_integration
-def test_create_missings(request, tmpdir):
+def test_create_missings(tmpdir):
     try:
         enough = create_enough(tmpdir, 'create-missings')
         r = enough.create_missings(['bind-host'])
@@ -309,7 +309,7 @@ def test_create_missings(request, tmpdir):
         bind_internal_ip = enough.openstack.server_ip_in_network('bind-host', 'internal')
         assert bind_internal_ip == internal_dns['dns_nameservers'][0]
     finally:
-        o = OpenStack(settings.CONFIG_DIR)
+        o = OpenStack(enough.config_dir)
         # comment out the following line to re-use the content of the regions and save time
         o.destroy_everything(None)
 
@@ -336,7 +336,7 @@ def test_volume_from_snapshot():
     assert Enough.volume_from_snapshot(snapshot) == volume
 
 
-def test_host_from_snapshot(request, tmpdir):
+def test_host_from_snapshot(tmpdir):
     e = create_enough(tmpdir, 'backup')
     host = 'sample-host'
     snapshot = f'2010-07-08-sample-volume'
@@ -344,7 +344,7 @@ def test_host_from_snapshot(request, tmpdir):
 
 
 @pytest.mark.openstack_integration
-def test_volume_resize(request, tmpdir):
+def test_volume_resize(tmpdir):
     try:
         enough = create_enough(tmpdir, 'resize')
         enough.set_args(name='sample', playbook='enough-playbook.yml')
@@ -356,7 +356,7 @@ def test_volume_resize(request, tmpdir):
         with pytest.raises(Enough.VolumeResizeNoSize):
             enough.volume_resize('nosize-host', 'nosize-volume')
     finally:
-        o = OpenStack(settings.CONFIG_DIR)
+        o = OpenStack(enough.config_dir)
         # comment out the following line to re-use the content of the regions and save time
         o.destroy_everything(None)
 
